@@ -1,31 +1,27 @@
 import asyncio
 import datetime
 import logging
-import os
 import random  # nosec
-from asyncio import subprocess
 
 from pysolar import solar
 
 logger = logging.getLogger(__package__)
 
 
-async def update_color(latitude, longitude, leds, clouds, sound, interval=5):
+async def update_color(
+    latitude, longitude, leds, power_btn, clouds, player, interval=5
+):
     warm, cold = leds
+    asyncio.Task(power_btn.listen())
     max_cloud_duration = 30
     cloudy = 0
-    player = None
-    if sound is not None and not os.path.isfile(sound):
-        raise ValueError("File does not exist: %s" % sound)
     while True:
         now = datetime.datetime.now(datetime.timezone.utc)
         sun_altitude_deg = solar.get_altitude(latitude, longitude, now)
         logger.info("Sun altitude: %.1fº", sun_altitude_deg)
 
-        if sound and player is None and sun_altitude_deg > -8:
-            player = await subprocess.create_subprocess_exec(
-                "ffplay", "-loop", "0", "-loglevel", "24", sound
-            )
+        if sun_altitude_deg > -8:
+            player.play()
 
         if sun_altitude_deg > 16:
             if cloudy:
@@ -46,7 +42,5 @@ async def update_color(latitude, longitude, leds, clouds, sound, interval=5):
         else:
             cold.value = 0
             warm.value = 0
-            if player is not None:
-                player.terminate()
-                player = None
+            player.stop()
         await asyncio.sleep(interval)
